
# Slot: min_delta


Minimum change in the monitored quantity to qualify as an improvement, i.e. an absolute change of less than min_delta, will count as no improvement.

URI: [https://w3id.org/neat/classifierCallback__min_delta](https://w3id.org/neat/classifierCallback__min_delta)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents


## Children


## Used by

 * [ClassifierCallback](ClassifierCallback.md)
